#
# spec file for package SDL_gfx
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lname	libSDL_gfx15
Name:           SDL_gfx
Version:        2.0.26
Release:        1.26
Summary:        SDL Graphics Routines for Primitives and Other Support Functions
License:        Zlib
Group:          Development/Libraries/X11
URL:            http://www.ferzkopp.net/wordpress/2016/01/02/sdl_gfx-sdl2_gfx/
Source:         http://www.ferzkopp.net/Software/SDL_gfx-2.0/%name-%version.tar.gz
Source2:        baselibs.conf
BuildRequires:  dos2unix
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(sdl)

%description
The SDL_gfx library evolved out of the SDL_gfxPrimitives code which
provided basic drawing routines such as lines, circles or polygons and
SDL_rotozoom which implemented a interpolating rotozoomer for SDL
surfaces.

%package -n %lname
Summary:        SDL Graphics Routines for Primitives and Other Support Functions
Group:          System/Libraries
Provides:       SDL_gfx = %version-%release
Obsoletes:      SDL_gfx < %version-%release

%description -n %lname
The SDL_gfx library evolved out of the SDL_gfxPrimitives code which
provided basic drawing routines such as lines, circles or polygons and
SDL_rotozoom which implemented a interpolating rotozoomer for SDL
surfaces.

%package -n libSDL_gfx-devel
Summary:        Libraries, includes and more to develop SDL_gfx applications
Group:          Development/Libraries/X11
Requires:       %lname = %version
Provides:       SDL_gfx-devel = %{version}
Obsoletes:      SDL_gfx-devel < %{version}

%description -n libSDL_gfx-devel
The SDL_gfx library evolved out of the SDL_gfxPrimitives code which
provided basic drawing routines such as lines, circles or polygons and
SDL_rotozoom which implemented a interpolating rotozoomer for SDL
surfaces. The current components of the SDL_gfx library are:

- Graphic Primitives (SDL_gfxPrimitves.h)

- Rotozoomer (SDL_rotozoom.h)

- Framerate control (SDL_framerate.h)

- MMX image filters (SDL_imageFilter.h)

The library is backwards compatible to the above mentioned code. It is
written in plain C and can be used in C++ code.

%prep
%setup -q

%build
# MMX code has a problem with uninitialized variables; we would only turn it
# on for x86_64 anyway - but that one can use SSE instead.
%configure --disable-static --disable-mmx
make %{?_smp_mflags}
dos2unix README
chmod 644 LICENSE AUTHORS ChangeLog NEWS README

%install
%make_install
find %buildroot -type f -name "*.la" -delete -print

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license LICENSE
%doc AUTHORS ChangeLog NEWS README
%_libdir/libSDL_gfx.so.15*

%files -n libSDL_gfx-devel
%_includedir/SDL/
%_libdir/lib*.so
%_libdir/pkgconfig/SDL_gfx.pc

%changelog
* Fri Aug 17 2018 bjorn.lie@gmail.com
- Readd SDL_gfx-devel Provides/Obsoletes, still needed.
* Thu Aug  9 2018 rpm@fthiessen.de
- Update to 2.0.26
  * Included patch for CMake builds against SDL2
  * Fixed bug in rotozoomSurfaceSizeTrig
* Thu Jan  8 2015 jengelh@inai.de
- Remove redundant requires
* Thu Dec 18 2014 jengelh@inai.de
- Use source URLs. Specfile cleanups.
* Mon Nov 11 2013 jengelh@inai.de
- Update to new upstream release 2.0.25
  * Unspecified bugfixes related to MMX support, _aaline,
  SDL_gfxBlitFunc.h, 32-bit RGBA blending function and pixel
  blend routine
- Set RPM groups to the same values as on the main SDL packages
- Own /usr/include/SDL as well
* Wed Feb 22 2012 jreidinger@suse.com
- update to version 2.0.23
  * Updated sources to resolve some splint (static code analysis)
    issues
  * Updates for OpenSDK (WinCE6/ARM) build target (patch contributed
    itsnotabigtruck)
  * Added OSX Xcode3+ template files to Other Builds collection
    (contributed by Vasyl)
  * Added various fixes and improvements contributed by folks on
    sourceforge (thanks contributors).
  * Switched library and test code to zlib license.
- fix self obsoletion
* Fri Sep 16 2011 jengelh@medozas.de
- Add libSDL_gfx-devel to baselibs
- Remove redundant tags/sections
* Sat Jul  2 2011 jengelh@medozas.de
- Use %%_smp_mflags for parallel building
- Strip %%clean section (not needed on BS)
* Mon Feb 21 2011 tzotsos@opensuse.org
- Updated to version 2.0.22
  * Fixed line width calculation for normal and textured polygons
    (patch contributed by Daniel (SupSuper)
  * Fixed version setup in configure.in
  * Added rounded rectangle and rounded box primitives
  * Updated test program for roundedbox + left/right-click support
  * Fixed pie calculation (line-case detection, end-angle clipping)
  * Updated DLL_EXPORT handling and added WIN64 test
    (patch contributed by tigerfishdaisy)
  * Added thick line primitive based on Murphy's algorithm
* Wed Jan 27 2010 jengelh@medozas.de
- package baselibs.conf
* Wed Oct  7 2009 prusnak@suse.cz
- fix provides and obsoletes [bnc#544957]
* Wed May 20 2009 prusnak@suse.cz
- follow Shared Library Policy
* Tue May 19 2009 prusnak@suse.cz
- updated to 2.0.19
  * gcc43 compiler patch for asm code in image filters
  * off-by-one hline patch for 1byte indexed surfaces
  * update acinclude.m4 from SDL-1.2 and moved # serial in file
  * applied patch to add pkg-config support for SDL_gfx
  * changed configure.in INTERFACE_AGE and BINARY_AGE
  * fixed zoom XY-flip code and made it available for all modes
    in zoom and rotations
  * fixed edge issue on interpolated rotozoom modes
  * updated TestRotozoom custom test mode, added delay parameter
  * added tests which include flipping, included negative rotation
  * update libtool files
  * updated Makefile.mingw
- updated to 2.0.18
  * libtool update for dependencies
  * fix uninitialised variables in _putPixelAlpha()
  * reverted to original alpha routine in _putPixelAlpha()
  * added colorkey handling patch to rotozoom
  * downgraded optimization to -O for asm compatibility with gcc4
* Wed Feb 25 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- correct -devel package dependencies
* Fri Jun 13 2008 sndirsch@suse.de
- update to release 2.0.17
  * hline/vline clipping and swap-logic fixed
  * clipping box dimension check added and clipping-checks optimized
  * TestFonts program updated
  * Updated documentation on cross-compilation, AMD64
  * Fixed circleColor overdraw
  * Added arcColor routine
  * Added polygonColorMT and polygonTextureMT routines
  * Updated 32bit alpha blending routine
* Sun Nov 18 2007 sndirsch@suse.de
- disable use of MMX on i386 to fix build with gcc 4.3
* Tue Feb  6 2007 sndirsch@suse.de
- updated to release 2.0.16
  * updated config.sub to newer version
  * added custom RGBA blitter function that sets/maintains target
    alpha
  * added setAlpha function that sets alpha values in 32bit
    surfaces
  * added TextGfxBlit testprogram for new functions
  * Fixed C++ type in .h files (thanks Olivier)
  * Update some text in README and .spec file
  * Removed broken Uint filter routines from test program
  * "Cosmetic" changes to test programs and Automake.am
* Sat Dec 23 2006 sndirsch@suse.de
- updated to release 2.0.15
  * bugfixes in 32bit _putPixelAlpha/filledRectAlpha (thanks CISC)
  * various bugfixes in return value generation and return (thanks CISC)
  * lock font-surface before using it (thanks CISC)
  * fix some breakage in non-MMX filter routines (thanks CISC)
  * fix typo in TestABGR (thanks CISC)
  * fix double buffer flipping in Tets programs (thanks CISC)
  * fixed microversion in .h
  * fixed texturePolygon inverted bug
  * fixed wrong surface use in test 21 of TestRotozoom
  * added pitch handling in font surface (thanks CISC)
* Wed Dec 20 2006 sndirsch@suse.de
- updated to release 2.0.14
  * added texturedPolygon routine to library (thanks Jees)
  * changed iterator condition in aaellipse to add some overdraw
    to smooth circle
  * added ShrinkImage routine to rotozoom code
  * added TestABGR Test program (bug in SDL_gfx or SDL??)
  * improved TestImageFilter program (bug in Uint filters)
  * changed .so versioning from .so.13.0.0 to .so.0.0.14
    (best is to remove all old libs before installing)
  * added updated MacOSX ProjectBuilder file (thanks Brian)
  * added info on MacOSX 10.3 build
  * added mingw (on cygwin) makefile (thanks Brian)
  * added Dev-Cpp makefile (thanks Sebastian)
  * removed some unused variables from gfx and rotozoom code
    (thanks Thi)
  * fixed a non-critical typecast mistake (thanks Thi)
  * converted all C++ comments to C comments in SDL_imageFilter
- random.diff:
  * fixed fatal build warnings for returning random data in a function
* Thu Sep 14 2006 nadvornik@suse.cz
- fixed Requires of devel subpackage [#192736]
* Fri Mar 10 2006 bk@suse.de
- SDL_gfx-devel: add libstdc++, gcc and gpm to Requires (.la check)
* Mon Jan 30 2006 ro@suse.de
- added gcc-c++ to BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Aug 14 2005 sndirsch@suse.de
- created package; useful e.g. for building lincity-ng
